@@ -34,6 +34,7 @@ void ChartDialog::languageChange()
 
 void ChartDialog::init()
 {
+    my.rateConvert = true;
     my.chartTreeSelected = false;
     my.availableTreeSelected = false;
     my.chartTreeSingleSelected = NULL;
@@ -70,21 +71,61 @@ void ChartDialog::init()
 	SIGNAL(newCol(QRgb)), this, SLOT(newColorTypedIn(QRgb)));
 }
 
-void ChartDialog::reset(Chart *chart, int style, QString scheme)
+void ChartDialog::reset()
 {
+    my.chart = NULL;
+
+    setWindowTitle(tr("New Chart"));
+    tabWidget->setCurrentIndex(1);
+    chartMetricsTreeWidget->clear();
+    titleLineEdit->setText(tr(""));
+    typeComboBox->setCurrentIndex((int)Chart::LineStyle - 1);
+    legendOn->setChecked(true);
+    legendOff->setChecked(false);
+    antiAliasingOn->setChecked(false);
+    antiAliasingOff->setChecked(false);
+    antiAliasingAuto->setChecked(true);
+    rateConvertCheckBox->setChecked(true);
+    rateConvertCheckBox->setEnabled(true);
+    setCurrentScheme(QString::null);
     my.sequence = 0;
-    my.scheme = scheme;
-    my.chart = chart;
-    if (!chart) {
-	setWindowTitle(tr("New Chart"));
-	tabWidget->setCurrentIndex(1);
-	chartMetricsTreeWidget->clear();
-    }
-    else {
-	setWindowTitle(tr("Edit Chart"));
-	tabWidget->setCurrentIndex(0);
-	setupChartMetricsTree();
-    }
+
+    resetCommon();
+}
+
+void ChartDialog::reset(Chart *cp)
+{
+    bool yAutoScale;
+    double yMin, yMax;
+
+    my.chart = cp;
+
+    setWindowTitle(tr("Edit Chart"));
+    tabWidget->setCurrentIndex(0);
+    setupChartMetricsTree();
+    titleLineEdit->setText(cp->title());
+    typeComboBox->setCurrentIndex(cp->style() - 1);
+    legendOn->setChecked(cp->legendVisible());
+    legendOff->setChecked(!cp->legendVisible());
+    antiAliasingOn->setChecked(cp->antiAliasing());
+    antiAliasingOff->setChecked(!cp->antiAliasing());
+    antiAliasingAuto->setChecked(false);
+    my.rateConvert = cp->rateConvert();
+    rateConvertCheckBox->setChecked(my.rateConvert);
+    rateConvertCheckBox->setEnabled(false);
+    cp->scale(&yAutoScale, &yMin, &yMax);
+    setScale(yAutoScale, yMin, yMax);
+    setScheme(cp->scheme(), cp->sequence());
+    setupSchemeComboBox();
+
+    resetCommon();
+}
+
+//
+// Code paths common to both Create/Edit dialog uses
+//
+void ChartDialog::resetCommon()
+{
     if ((my.archiveSource = pmchart->isArchiveTab()) == true) {
 	sourceButton->setToolTip(tr("Add archives"));
 	sourceButton->setIcon(QIcon(":/archive.png"));
@@ -93,18 +134,9 @@ void ChartDialog::reset(Chart *chart, int style, QString scheme)
 	sourceButton->setToolTip(tr("Add a host"));
 	sourceButton->setIcon(QIcon(":/computer.png"));
     }
-    titleLineEdit->setText(tr(""));
-    typeComboBox->setCurrentIndex(style);
-    setupSchemeComboBox();
-    legendOn->setChecked(true);
-    legendOff->setChecked(false);
-    antiAliasingOn->setChecked(false);
-    antiAliasingOff->setChecked(false);
-    antiAliasingAuto->setChecked(true);
     setupAvailableMetricsTree(my.archiveSource == true);
     my.yMin = yAxisMinimum->value();
     my.yMax = yAxisMaximum->value();
-
     my.chartTreeSelected = false;
     my.availableTreeSelected = false;
     my.chartTreeSingleSelected = NULL;
@@ -147,13 +179,14 @@ void ChartDialog::enableUi()
     }
 }
 
-void ChartDialog::buttonOk_clicked()
+//
+// Verify user input and don't dismiss dialog (OK) if problems found.
+// Needs to handle many cases: New Chart (!my.chart) and Edit Chart,
+// as well as Apply and OK.
+//
+bool ChartDialog::validate(QString &message, int &index)
 {
-    // Verify user input and don't dismiss the dialog if problems found.
-    // Needs to handle both cases: New Chart (!my.chart) and Edit Chart.
-    bool validInput = true;
-    QString message;
-    int index = 0;
+    bool validInput;
 
     // Check some plots have been selected.
     if (!my.chart && chartMetricsTreeWidget->topLevelItemCount() == 0 &&
@@ -179,9 +212,47 @@ void ChartDialog::buttonOk_clicked()
 	validInput = false;
 	index = 1;
     }
+    else {
+	validInput = true;
+	index = 0;
+    }
+    return validInput;
+}
 
-    if (validInput)
+void ChartDialog::buttonOk_clicked()
+{
+    QString message;
+    int index;
+
+    if (validate(message, index)) {
+	if (my.chart)
+	    pmchart->acceptEditChart();
+	else
+	    pmchart->acceptNewChart();
 	QDialog::accept();
+    } else {
+	tabWidget->setCurrentIndex(index);
+	QMessageBox::warning(this, pmProgname, message,
+		    QMessageBox::Ok|QMessageBox::Default|QMessageBox::Escape,
+		    Qt::NoButton, Qt::NoButton);
+    }
+}
+
+void ChartDialog::buttonApply_clicked()
+{
+    QString message;
+    int index;
+
+    if (validate(message, index)) {
+	if (my.chart) {
+	    pmchart->acceptEditChart();
+	    reset(my.chart);
+	}
+	else {
+	    pmchart->acceptNewChart();
+	    reset();
+	}
+    }
     else {
 	tabWidget->setCurrentIndex(index);
 	QMessageBox::warning(this, pmProgname, message,
@@ -459,6 +530,21 @@ void ChartDialog::yAxisMaximumValueChanged(double value)
     my.yMax = value;
 }
 
+void ChartDialog::rateConvertClicked()
+{
+    my.rateConvert = rateConvertCheckBox->isChecked();
+}
+
+bool ChartDialog::rateConvert()
+{
+    return my.rateConvert;
+}
+
+void ChartDialog::setRateConvert(bool rateConvert)
+{
+    my.rateConvert = rateConvert;
+}
+
 // Sets all widgets to display h,s,v
 void ChartDialog::newHsv(int h, int s, int v)
 {
