@@ -52,7 +52,7 @@ public:
     static double defaultLoggerDelta() { return 1.0; }
     static int defaultVisibleHistory() { return 60; }	// points
     static int defaultSampleHistory() { return 180; }
-    static int defaultTimeout() { return 3000; }		// milliseconds
+    static int defaultTimeout() { return 8000; }		// milliseconds
     static int minimumPoints() { return 2; }
     static int maximumPoints() { return 360; }
     static int maximumLegendLength() { return 120; }	// chars
@@ -65,6 +65,7 @@ public:
     bool isTabRecording();
     TabWidget *tabWidget() { return chartTabWidget; }
     TimeAxis *timeAxis() { return my.statusBar->timeAxis(); }
+    QLabel *dateLabel() { return my.statusBar->dateLabel(); }
 
     virtual void step(bool livemode, PmTime::Packet *pmtime);
     virtual void VCRMode(bool livemode, PmTime::Packet *pmtime, bool drag);
@@ -73,7 +74,7 @@ public:
     virtual void setupAssistant();
     virtual void updateHeight(int);
     virtual void createNewChart();
-    virtual void metricInfo(QString src, QString m, QString inst, bool archive);
+    virtual void metricInfo(QString src, QString m, QString inst, int srcType);
     virtual void metricSearch(QTreeWidget *pmns);
     virtual void createNewTab(bool liveMode);
     virtual void setValueText(QString &text);
@@ -94,7 +95,7 @@ public:
     virtual void newScheme(QString);	// reply back to requesting dialog(s)
     virtual void updateBackground();
 
-    void painter(QPainter *, int w, int h, bool);
+    void painter(QPainter *qp, int pw, int ph, bool transparent, bool currentOnly);
 
     // Adjusted height for exporting images (without UI elements)
     int exportHeight()
@@ -114,7 +115,6 @@ public slots:
     virtual void fileQuit();
     virtual void assistantError(const QString &);
     virtual void helpManual();
-    virtual void helpTutorial();
     virtual void helpAbout();
     virtual void helpSeeAlso();
     virtual void whatsThis();
